import React from "react";
import { loadFeature, defineFeature } from "jest-cucumber";
import {
  render,
  screen /* , act, fireEvent, waitForElementToBeRemoved*/
} from "@testing-library/react";
import App from "../App";
import { server } from "../mocks/server";
import { rest } from "msw";
import { createMemoryHistory } from "history";

// mock BrowserRouter (this should probably live somewhere else)
const reactRouterDom = require("react-router-dom");
reactRouterDom.BrowserRouter = ({ children }) => <div>{children}</div>;
const Router = reactRouterDom.Router;

const feature = loadFeature("features/hosts/browse-hosts.feature");

defineFeature(feature, (test) => {
  test("User wants to browse IOC hosts", ({ given, when, then }) => {
    given("the user is logged in", () => {
      const history = createMemoryHistory();
      history.push("/hosts");
      render(
        <Router history={history}>
          <App />
        </Router>
      );
    });

    when("the user navigates to the hosts page", async () => {
      await screen.findByText("CE deploy & monitor / IOC hosts");
    });

    then(
      "they should be presented with a table of hosts from the iocs group in CSEntry",
      async () => {
        expect(
          await screen.findByText("CE deploy & monitor / IOC hosts")
        ).toBeInTheDocument();
        expect(await screen.findByText("Status")).toBeInTheDocument();
        expect(await screen.findByText("Host")).toBeInTheDocument();
        expect(await screen.findByText("Network")).toBeInTheDocument();
        expect(await screen.findByText("Scope")).toBeInTheDocument();
      }
    );
  });

  test("User wants to navigate to a specific IOC Host", ({
    given,
    when,
    then,
    and
  }) => {
    const history = createMemoryHistory();
    given("the user is on the hosts page", async () => {
      server.use(
        rest.get("*/hosts", (req, res, ctx) => {
          return res(
            ctx.json({
              totalCount: 0,
              listSize: 1,
              pageNumber: 0,
              limit: 100,
              csEntryHosts: [
                {
                  csEntryHost: {
                    id: 3057,
                    fqdn: "ccce-demo-01.tn.esss.lu.se",
                    name: "ccce-demo-01",
                    scope: "TechnicalNetwork",
                    description: null,
                    user: "johnsparger",
                    interfaces: [
                      {
                        id: 3494,
                        name: "ccce-demo-01",
                        network: "ChannelAccess-ACC",
                        domain: "tn.esss.lu.se",
                        ip: "172.16.100.61",
                        mac: "02:42:42:1f:38:53",
                        host: "ccce-demo-01",
                        cnames: [],
                        is_main: true
                      }
                    ],
                    is_ioc: true,
                    device_type: "VirtualMachine",
                    created_at: "2021-02-12T12:07:00.000+00:00",
                    ansible_vars: {
                      vm_owners: ["johnsparger"]
                    },
                    ansible_groups: []
                  },
                  assigned: false,
                  status: "AVAILABLE"
                }
              ]
            })
          );
        }),
        rest.get("*/hosts/:hostId", (req, res, ctx) => {
          const { hostId } = req.params;
          return res(
            ctx.json({
              csEntryHosts: [
                {
                  csEntryHost: {
                    id: hostId,
                    fqdn: "ccce-demo-01.tn.esss.lu.se",
                    name: "ccce-demo-01",
                    scope: "TechnicalNetwork",
                    description: null,
                    user: "johnsparger",
                    interfaces: [
                      {
                        id: 3494,
                        name: "ccce-demo-01",
                        network: "ChannelAccess-ACC",
                        domain: "tn.esss.lu.se",
                        ip: "172.16.100.61",
                        mac: "02:42:42:1f:38:53",
                        host: "ccce-demo-01",
                        cnames: [],
                        is_main: true
                      }
                    ],
                    is_ioc: true,
                    deviceType: "VirtualMachine",
                    created_at: "2021-02-12T12:07:00.000+00:00",
                    ansible_vars: {
                      vm_owners: ["johnsparger"]
                    },
                    ansible_groups: []
                  },
                  assigned: false,
                  status: "AVAILABLE"
                }
              ],
              assigned: false,
              status: "AVAILABLE"
            })
          );
        })
      );

      history.push("/hosts");
      render(
        <Router history={history}>
          <App />
        </Router>
      );
      // await screen.findByText('ccce-demo-01.tn.esss.lu.se');
    });

    when("the user clicks (exactly) on the host url link", async () => {
      /* act(() => {
        fireEvent.click(screen.getByText('ccce-demo-01.tn.esss.lu.se'));
      });
      await waitForElementToBeRemoved(() => screen.getByText('Status'));

      history.push('/hosts/3057')
      render(
        <Router history={history}>
          <App />
        </Router>
      )

      await screen.findByTestId("host-details-container")*/
    });

    then("the user should be redirected to the Host Details page", async () => {
      // expect(await screen.findByText('Syslog info')).toBeInTheDocument()
    });
  });

  test("User wants to search for an IOC host", ({ given, when, then }) => {
    given("the user is on the hosts page", () => {});

    when("the user types a query in the search bar", () => {});

    then("the hosts table should be updated with the search results", () => {});
  });

  test("There are more hosts than can be displayed", ({
    given,
    when,
    then
  }) => {
    given("the user is on the hosts page", () => {});

    when(
      "there are more hosts matching the search query than can be displayed",
      () => {}
    );

    then(
      "a warning should be shown letting the user know that all hosts are not rendered",
      () => {}
    );
  });
});
