/**
 * GitRefLink
 * Component providing link (and tag) to gitlab
 */
import React from "react";
import { Typography, Link as MuiLink } from "@material-ui/core";
import { string } from "prop-types";

const propTypes = {
  /** String containing url to gitlab template */
  url: string,
  /**  String containing gitlab tag */
  revision: string
};

export default function GitRefLink({ url, revision }) {
  // if no git reference has been entered
  if (!url || url.trim === "") {
    return <></>;
  }

  // if user enters GIT url with '.git' postfix -> remove it
  if (url.toLowerCase().endsWith(".git")) {
    url = url.toLowerCase().split(".git")[0];
  }

  // add trailing '/' if needed for GIT server address
  if (!url.endsWith("/")) {
    url += "/";
  }

  // calculate the endpoint for tag/commitId
  url = url + "-/tree/" + revision;

  return (
    <Typography display="inline">
      <MuiLink
        href={url}
        target="_blank"
        rel="noreferrer"
      >
        {revision}
      </MuiLink>
    </Typography>
  );
}

GitRefLink.propTypes = propTypes;
