import React from "react";
import {
  CheckCircleOutline,
  ErrorOutline,
  RotateRightOutlined,
  QueueOutlined,
  ClearOutlined
} from "@material-ui/icons";
import { Tooltip } from "@material-ui/core";
import { theme } from "../../style/Theme";
import { RocketLaunch } from "../../icons/RocketLaunch";

export function DeploymentStatusIcon({ status }) {
  const deploymentStatusIcons = {
    successful: (
      <Tooltip title="Successful">
        <CheckCircleOutline />
      </Tooltip>
    ),
    failed: (
      <Tooltip title="Failed">
        <ErrorOutline />
      </Tooltip>
    ),
    running: (
      <Tooltip title="Running">
        <RotateRightOutlined />
      </Tooltip>
    ),
    queued: (
      <Tooltip title="Queued">
        <QueueOutlined />
      </Tooltip>
    )
  };

  const deploymentStatusColors = {
    successful: theme.palette.status.ok,
    failed: theme.palette.status.fail,
    running: theme.palette.status.progress,
    queued: theme.palette.status.progress
  };

  const state = status.toLowerCase();
  const iconStyle = { fill: deploymentStatusColors[state] };
  const icon = React.cloneElement(deploymentStatusIcons[state], {
    style: iconStyle
  });

  return icon;
}

export function DeploymentTypeIcon({ type }) {
  const deploymentTypeIcons = {
    deploy: <RocketLaunch />,
    undeploy: (
      <Tooltip title="Undeployment">
        <ClearOutlined />
      </Tooltip>
    )
  };

  const icon = React.cloneElement(deploymentTypeIcons[type.toLowerCase()]);

  return icon;
}
