import { Box, Button, Container, Grid, Typography } from "@material-ui/core";
import { BugReport } from "@material-ui/icons";
import React, { useCallback, useState } from "react";
import { ErrorBoundary, useErrorHandler } from "react-error-boundary";
import { useEffectOnMount } from "../../../hooks/MountEffects";
import { theme } from "../../../style/Theme";

function AwSnap({ error, resetErrorBoundary }) {
  const [showStack, setShowStack] = useState(false);

  const toggleStack = () => {
    setShowStack(!showStack);
  };

  console.log("AwSnap", error);
  return (
    <>
      <Grid
        container
        justifyContent="center"
      >
        <BugReport
          style={{ fontSize: 128, color: theme.palette.primary.main }}
        />
      </Grid>
      <Grid
        container
        justifyContent="center"
      >
        <h1 style={{ textAlign: "center" }}>
          💥 Whoops! Something went wrong 💥
        </h1>
      </Grid>
      <Grid
        container
        justifyContent="center"
      >
        <Typography variant="body1">
          If this error persists, please contact the{" "}
          <a href="https://ess-eric.slack.com/archives/C01V3R31EP2">
            CCCE team
          </a>
        </Typography>
      </Grid>
      <Grid
        container
        justifyContent="center"
        spacing={2}
      >
        <Grid item>
          <Button
            variant="contained"
            color="secondary"
            style={{ backgroundColor: theme.palette.primary.main }}
            onClick={resetErrorBoundary}
          >
            Reload
          </Button>
        </Grid>
        <Grid item>
          <Button
            variant="contained"
            color="secondary"
            style={{ backgroundColor: theme.palette.primary.main }}
            onClick={toggleStack}
          >
            {showStack ? "Hide Details" : "Show details"}
          </Button>
        </Grid>
      </Grid>
      {showStack ? (
        <Grid
          container
          justifyContent="center"
        >
          <Box
            p={10}
            overflow="auto"
          >
            <pre>{error.stack}</pre>
          </Box>
        </Grid>
      ) : null}
    </>
  );
}

function WindowErrorRedirect({ children }) {
  const handleError = useErrorHandler();
  const onError = useCallback(
    (event) => {
      handleError(event.error ?? event.reason);
    },
    [handleError]
  );

  useEffectOnMount(() => {
    window.addEventListener("error", onError);
    window.addEventListener("unhandledrejection", onError);
    return function cleanup() {
      window.removeEventListener("error", onError);
      window.removeEventListener("unhandledrejection", onError);
    };
  });

  return children;
}

export function AppErrorBoundary({ children }) {
  return (
    <ErrorBoundary
      FallbackComponent={AwSnap}
      onReset={() => {
        window.location.href = "/";
      }}
    >
      <WindowErrorRedirect>{children}</WindowErrorRedirect>
    </ErrorBoundary>
  );
}

export function Break() {
  const [broken, setBroken] = useState(false);
  const Bomb = ({ where }) => {
    throw new Error(`KABOOM: You broke the UI ${where}`);
  };
  return (
    <Container>
      <Button
        variant="contained"
        onClick={() => setBroken(true)}
      >
        Break the UI during render
      </Button>
      {broken && <Bomb where="during Render" />}
      <Button
        variant="contained"
        onClick={(event) => {
          Bomb({ where: "in a Callback" });
        }}
      >
        Break the UI asynchronously
      </Button>
    </Container>
  );
}
