import React, { useEffect, useCallback } from "react";
import { useRecordSearch } from "../../api/SwaggerApi";
import { initRequestParams } from "../common/Helper";
import { RecordTable } from "./RecordTable";
import { SearchBar } from "../common/SearchBar/SearchBar";
import useUrlState from "@ahooksjs/use-url-state";
import { serialize, deserialize } from "../common/URLState/URLState";

export function RecordSearch({ iocName, rowType }) {
  const [records, getRecords /* reset*/, , loading] = useRecordSearch();
  const [state, setState] = useUrlState({ rows: "20", page: "0", query: "" });

  const lazyParams = useCallback(() => {
    return {
      rows: deserialize(state.rows),
      page: deserialize(state.page)
    };
  }, [state]);

  const setLazyParams = useCallback(
    (params) => {
      setState({ rows: serialize(params.rows), page: serialize(params.page) });
    },
    [setState]
  );

  const rowsPerPage = [20, 50];

  useEffect(() => {
    let requestParams = initRequestParams(lazyParams());
    const query = deserialize(state.query);
    if (query && query.length > 0) {
      requestParams = {
        ...requestParams,
        record_name: "*" + query + "*"
      };
    }
    if (iocName && iocName.length > 0) {
      requestParams = {
        ...requestParams,
        ioc_name: iocName
      };
    }
    getRecords(requestParams);
  }, [getRecords, lazyParams, iocName, state]);

  const setSearch = useCallback(
    (query) => {
      setState({ query: serialize(query) });
    },
    [setState]
  );

  return (
    <SearchBar
      search={setSearch}
      query={deserialize(state.query)}
      loading={loading}
      placeholder="Search in Record"
    >
      <RecordTable
        records={records}
        rowType={rowType}
        loading={loading}
        lazyParams={lazyParams()}
        setLazyParams={setLazyParams}
        rowsPerPage={rowsPerPage}
      />
    </SearchBar>
  );
}
