import React from "react";
import { SnackbarProvider } from "notistack";
import { Container, ThemeProvider } from "@material-ui/core";
import { theme } from "../style/Theme";
import { APIProvider, UserProvider } from "../api/SwaggerApi";
import { NotificationProvider } from "../components/common/notification/Notifications";
import { GlobalAppBar } from "../components/navigation/GlobalAppBar/GlobalAppBar";
import { MemoryRouter } from "react-router-dom";

export function AppHarness({ children, initialHistory = ["/"] }) {
  return (
    <SnackbarProvider
      preventDuplicate
      maxSnack="5"
    >
      <ThemeProvider theme={theme}>
        <MemoryRouter initialEntries={initialHistory}>
          <APIProvider>
            <UserProvider>
              <NotificationProvider>
                <GlobalAppBar>
                  <Container>{children}</Container>
                </GlobalAppBar>
              </NotificationProvider>
            </UserProvider>
          </APIProvider>
        </MemoryRouter>
      </ThemeProvider>
    </SnackbarProvider>
  );
}

export function RouterHarness({ children, initialHistory = ["/"] }) {
  return (
    <ThemeProvider theme={theme}>
      <MemoryRouter initialEntries={initialHistory}>{children}</MemoryRouter>
    </ThemeProvider>
  );
}
