import { Card, CardContent, Grid } from "@material-ui/core";
import React, { useContext, useEffect } from "react";
import { useLocation } from "react-router-dom";
import { userContext } from "../../api/SwaggerApi";
import { LoginForm } from "../../components/auth/Login";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { useRedirect } from "../../hooks/Redirect";

export function LoginView() {
  useGlobalAppBar("Login", null);
  const redirect = useRedirect();

  const { user, login, loginError, resetLoginError } = useContext(userContext);
  const location = useLocation();

  useEffect(() => {
    if (user) {
      const goTo = location.state?.from ?? "/home";
      redirect(goTo, {}, true);
    }
  }, [location.state?.from, redirect, user]);

  return (
    <Grid
      container
      spacing={0}
      alignItems="center"
      justify="center"
      style={{ minHeight: "80vh" }}
    >
      <Grid
        item
        xs={8}
        md={5}
        xl={3}
      >
        <Card>
          <CardContent>
            <LoginForm
              login={login}
              error={loginError}
              resetError={resetLoginError}
            />
          </CardContent>
        </Card>
      </Grid>
    </Grid>
  );
}
